<?php

namespace Btravel\Attribute\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Attribute\Models\AttributeCategory;

class AttributeCategoryPolicy
{

    /**
     * Determine if the given user can view the attribute_category.
     *
     * @param UserPolicy $user
     * @param AttributeCategory $attribute_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, AttributeCategory $attribute_category)
    {
        if ($user->canDo('attribute.attribute_category.view') && $user->isAdmin()) {
            return true;
        }

        return $attribute_category->user_id == user_id() && $attribute_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a attribute_category.
     *
     * @param UserPolicy $user
     * @param AttributeCategory $attribute_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('attribute.attribute_category.create');
    }

    /**
     * Determine if the given user can update the given attribute_category.
     *
     * @param UserPolicy $user
     * @param AttributeCategory $attribute_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, AttributeCategory $attribute_category)
    {
        if ($user->canDo('attribute.attribute_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $attribute_category->user_id == user_id() && $attribute_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given attribute_category.
     *
     * @param UserPolicy $user
     * @param AttributeCategory $attribute_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, AttributeCategory $attribute_category)
    {
        return $attribute_category->user_id == user_id() && $attribute_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given attribute_category.
     *
     * @param UserPolicy $user
     * @param AttributeCategory $attribute_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, AttributeCategory $attribute_category)
    {
        if ($user->canDo('attribute.attribute_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attribute_category.
     *
     * @param UserPolicy $user
     * @param AttributeCategory $attribute_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, AttributeCategory $attribute_category)
    {
        if ($user->canDo('attribute.attribute_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
