<?php

namespace Btravel\Attribute\Providers;

use Illuminate\Support\ServiceProvider;

class AttributeServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'attribute');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'attribute');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerAttribute();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerAttribute()
    {
        $this->app->bind('attribute', function($app) {
            return new Attribute($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Attribute', 'Lavalite\Attribute\Facades\Attribute');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('btravel.attribute', function ($app) {
            return $this->app->make('Btravel\Attribute\Attribute');
        });

        // Bind Attribute to repository
        $this->app->bind(
            'Btravel\Attribute\Interfaces\AttributeRepositoryInterface',
            \Btravel\Attribute\Repositories\Eloquent\AttributeRepository::class
        );
        // Bind AttributeCategory to repository
        $this->app->bind(
            'Btravel\Attribute\Interfaces\AttributeCategoryRepositoryInterface',
            \Btravel\Attribute\Repositories\Eloquent\AttributeCategoryRepository::class
        );

        $this->app->register(\Btravel\Attribute\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Btravel\Attribute\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and attribute's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/attribute.php', 'attribute'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeAttribute::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['btravel.attribute'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('btravel/attribute.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/attribute')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/attribute')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
