<?php

namespace Btravel\Attribute\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Btravel\Attribute\Models\Attribute;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Btravel\Attribute\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/attribute/attribute/*')) {
            Route::bind('attribute', function ($attribute) {
                $attributerepo = $this->app->make('Btravel\Attribute\Interfaces\AttributeRepositoryInterface');
                return $attributerepo->findorNew($attribute);
            });
        }

        if (Request::is('*/attribute/attribute_category/*')) {
            Route::bind('attribute_category', function ($attribute_category) {
                $attribute_categoryrepo = $this->app->make('Btravel\Attribute\Interfaces\AttributeCategoryRepositoryInterface');
                return $attribute_categoryrepo->findorNew($attribute_category);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
